from datetime import datetime
from typing import Optional
from sqlmodel import Field, MetaData, SQLModel

# 1. MetaData 객체 생성 시 schema 지정
#    (모든 테이블이 동일한 스키마를 공유할 경우)
SCHEMA_NAME = "cs2002"
metadata = MetaData(schema=SCHEMA_NAME)


class Base(SQLModel):
    metadata = metadata


class Wj(Base, table=True):
    __tablename__ = "wj"  # type: ignore

    wj_auto: Optional[int] = Field(
        default=None, primary_key=True, sa_column_kwargs={"autoincrement": "auto"}
    )
    wj_chart: str = Field(max_length=8)
    wj_suname: str = Field(max_length=50)
    wj_birthday: str = Field(max_length=8)


class Ns(Base, table=True):
    __tablename__ = "ns"  # type: ignore

    ns_auto: Optional[int] = Field(
        default=None, primary_key=True, sa_column_kwargs={"autoincrement": "auto"}
    )
    ns_chart: str = Field(max_length=8)
    ns_ymd: str = Field(max_length=50)
    ns_neyong1: str = Field()
    ns_neyong2: str = Field()


class LtcDrgList(Base, table=True):
    __tablename__ = "ltcdrglist"  # type: ignore

    ldl_auto: Optional[int] = Field(
        default=None, primary_key=True, sa_column_kwargs={"autoincrement": "auto"}
    )
    ldl_version: str = Field(max_length=6, default="")
    ldl_ymd: str = Field(max_length=8)
    ldl_saup: str = Field(max_length=2)
    ldl_chart: str = Field(max_length=8)
    ldl_yuhyung: str = Field(max_length=2)
    ldl_ibymd: str = Field(max_length=8)
    ldl_startymd: str = Field(max_length=8)
    ldl_jinchal: str = Field(max_length=2, default="")
    ldl_index: str = Field(max_length=1, default="0")
    ldl_change: str = Field(max_length=1, default="0")
    ldl_beginymd: str = Field(max_length=8)
    ldl_yoyangkiho: Optional[str] = Field(max_length=8, default="")
    ldl_suname: Optional[str] = Field(max_length=50, default="")
    ldl_sex: Optional[str] = Field(max_length=1, default="")
    ldl_nai: Optional[str] = Field(max_length=3, default="")
    ldl_jumin: Optional[str] = Field(max_length=48, default="")
    ldl_byungsil: Optional[str] = Field(max_length=15, default="")
    ldl_gubun: Optional[str] = Field(max_length=1, default="")
    ldl_stay: Optional[str] = Field(max_length=1, default="")
    ldl_career: Optional[str] = Field(max_length=1, default="")
    ldl_bphigh: Optional[int] = Field(default=0)
    ldl_bplow: Optional[int] = Field(default=0)
    ldl_a10_a: Optional[int] = Field(default=0)
    ldl_a10_b: Optional[int] = Field(default=0)
    ldl_a10_c: Optional[int] = Field(default=0)
    ldl_a10_d: Optional[int] = Field(default=0)
    ldl_a11: Optional[int] = Field(default=1)
    ldl_a12_a: Optional[int] = Field(default=0)
    ldl_a12_b1: Optional[int] = Field(default=0)
    ldl_a12_b2: Optional[int] = Field(default=0)
    ldl_a12_b3: Optional[int] = Field(default=0)
    ldl_a12_b4: Optional[int] = Field(default=0)
    ldl_a12_b5: Optional[int] = Field(default=0)
    ldl_a12_b6: Optional[int] = Field(default=0)
    ldl_a12_b7: Optional[int] = Field(default=0)
    ldl_a12_b8: Optional[int] = Field(default=0)
    ldl_a13: Optional[int] = Field(default=0)
    ldl_a14_a: Optional[int] = Field(default=0)
    ldl_a14_b: Optional[int] = Field(default=0)
    ldl_a14_c: Optional[int] = Field(default=0)
    ldl_a14_d: Optional[int] = Field(default=0)
    ldl_a14_e: Optional[int] = Field(default=0)
    ldl_a14_f: Optional[int] = Field(default=0)
    ldl_a14_g: Optional[int] = Field(default=0)
    ldl_b1: Optional[int] = Field(default=0)
    ldl_b2: Optional[str] = Field(max_length=1, default="")
    ldl_c1: Optional[str] = Field(max_length=1, default="")
    ldl_c2: Optional[str] = Field(max_length=1, default="")
    ldl_c3: Optional[str] = Field(max_length=1, default="")
    ldl_c4: Optional[str] = Field(max_length=1, default="")
    ldl_c5_a: Optional[str] = Field(max_length=1, default="")
    ldl_c5_b: Optional[str] = Field(max_length=1, default="")
    ldl_c5_c: Optional[str] = Field(max_length=1, default="")
    ldl_c5_d: Optional[str] = Field(max_length=1, default="")
    ldl_c5_e: Optional[str] = Field(max_length=1, default="")
    ldl_c5_f: Optional[str] = Field(max_length=1, default="")
    ldl_c5_g: Optional[str] = Field(max_length=1, default="")
    ldl_c5_h: Optional[str] = Field(max_length=1, default="")
    ldl_c5_i: Optional[str] = Field(max_length=1, default="")
    ldl_c5_j: Optional[str] = Field(max_length=1, default="")
    ldl_c5_k: Optional[str] = Field(max_length=1, default="")
    ldl_c5_l: Optional[str] = Field(max_length=1, default="")
    ldl_c5_m: Optional[str] = Field(max_length=1, default="")
    ldl_c5_n: Optional[str] = Field(max_length=1, default="")
    ldl_c6_a: Optional[str] = Field(max_length=1, default="")
    ldl_c6_b1: Optional[int] = Field(default=0)
    ldl_c6_b2: Optional[str] = Field(max_length=8, default="")
    ldl_c7_a: Optional[int] = Field(default=0)
    ldl_c7_b1: Optional[float] = Field(default=0)
    ldl_c7_b2: Optional[str] = Field(max_length=8, default="")
    ldl_c7_c: Optional[int] = Field(default=0)
    ldl_c7_d1: Optional[int] = Field(default=0)
    ldl_c7_d2: Optional[str] = Field(max_length=8, default="")
    ldl_d1: Optional[int] = Field(default=0)
    ldl_d2: Optional[int] = Field(default=0)
    ldl_d3: Optional[int] = Field(default=0)
    ldl_d4: Optional[int] = Field(default=0)
    ldl_d5: Optional[int] = Field(default=0)
    ldl_d6: Optional[int] = Field(default=0)
    ldl_d7: Optional[int] = Field(default=0)
    ldl_d8: Optional[int] = Field(default=0)
    ldl_d9: Optional[int] = Field(default=0)
    ldl_d10: Optional[int] = Field(default=0)
    ldl_d11: Optional[int] = Field(default=0)
    ldl_d12_a: Optional[int] = Field(default=0)
    ldl_d12_b: Optional[int] = Field(default=0)
    ldl_d12_c: Optional[int] = Field(default=0)
    ldl_e1: Optional[int] = Field(default=0)
    ldl_e2: Optional[int] = Field(default=0)
    ldl_e3_a: Optional[int] = Field(default=0)
    ldl_e3_b: Optional[int] = Field(default=0)
    ldl_e3_c: Optional[int] = Field(default=0)
    ldl_e3_d: Optional[int] = Field(default=0)
    ldl_e3_e: Optional[int] = Field(default=0)
    ldl_e3_f: Optional[int] = Field(default=0)
    ldl_e3_g: Optional[int] = Field(default=0)
    ldl_e3_g1: Optional[str] = Field(max_length=8, default="")
    ldl_e3_g1_1: str = Field(max_length=8)
    ldl_e3_g1_2: str = Field(max_length=8)
    ldl_e3_g2_1: str = Field(max_length=8)
    ldl_e3_g2_2: str = Field(max_length=8)
    ldl_e3_g3_1: str = Field(max_length=8)
    ldl_e3_g3_2: str = Field(max_length=8)
    ldl_e3_g4_1: str = Field(max_length=8)
    ldl_e3_g4_2: str = Field(max_length=8)
    ldl_e3_g5_1: str = Field(max_length=8)
    ldl_e3_g5_2: str = Field(max_length=8)
    ldl_e3_g6_1: str = Field(max_length=8)
    ldl_e3_g6_2: str = Field(max_length=8)
    ldl_e3_g7_1: str = Field(max_length=8)
    ldl_e3_g7_2: str = Field(max_length=8)
    ldl_e3_g8_1: str = Field(max_length=8)
    ldl_e3_g8_2: str = Field(max_length=8)
    ldl_e3_g9_1: str = Field(max_length=8)
    ldl_e3_g9_2: str = Field(max_length=8)
    ldl_e3_g10_1: str = Field(max_length=8)
    ldl_e3_g10_2: str = Field(max_length=8)
    ldl_e3_g11: int = Field()
    ldl_e3_h: Optional[int] = Field(default=0)
    ldl_e4: Optional[int] = Field(default=0)
    ldl_e4_a: int = Field()
    ldl_e4_b: int = Field()
    ldl_f1_a: Optional[int] = Field(default=0)
    ldl_f1_a1_a: Optional[str] = Field(max_length=1, default="")
    ldl_f1_a1_b1: Optional[int] = Field(default=0)
    ldl_f1_a1_b2: Optional[int] = Field(default=0)
    ldl_f1_a2_a: Optional[str] = Field(max_length=1, default="")
    ldl_f1_a2_b1: Optional[float] = Field(default=0)
    ldl_f1_a2_b2: Optional[str] = Field(max_length=8, default="")
    ldl_f1_b: Optional[int] = Field(default=0)
    ldl_f1_c: Optional[int] = Field(default=0)
    ldl_f1_d: Optional[int] = Field(default=0)
    ldl_f1_e: Optional[int] = Field(default=0)
    ldl_f1_f: Optional[int] = Field(default=0)
    ldl_f1_g: Optional[int] = Field(default=0)
    ldl_f1_h: Optional[int] = Field(default=0)
    ldl_f1_i: Optional[int] = Field(default=0)
    ldl_f1_j: Optional[int] = Field(default=0)
    ldl_f1_k: Optional[int] = Field(default=0)
    ldl_f1_l: Optional[int] = Field(default=0)
    ldl_f1_m: Optional[int] = Field(default=0)
    ldl_f1_n: Optional[int] = Field(default=0)
    ldl_f1_o: Optional[int] = Field(default=0)
    ldl_f1_p: Optional[int] = Field(default=0)
    ldl_f1_q: Optional[int] = Field(default=0)
    ldl_f1_r: Optional[int] = Field(default=0)
    ldl_f1_s: Optional[int] = Field(default=0)
    ldl_f1_t: Optional[int] = Field(default=0)
    ldl_f1_u: Optional[int] = Field(default=0)
    ldl_f1_v: Optional[int] = Field(default=0)
    ldl_f1_w: Optional[int] = Field(default=0)
    ldl_f1_x: Optional[int] = Field(default=0)
    ldl_f1_y: Optional[int] = Field(default=0)
    ldl_f1_z: Optional[int] = Field(default=0)
    ldl_f1_aa: Optional[int] = Field(default=0)
    ldl_f1_ab: Optional[int] = Field(default=0)
    ldl_f2_a: Optional[int] = Field(default=0)
    ldl_f2_b: Optional[int] = Field(default=0)
    ldl_f2_c: Optional[int] = Field(default=0)
    ldl_f2_d: Optional[int] = Field(default=0)
    ldl_f2_e: Optional[int] = Field(default=0)
    ldl_f2_f: Optional[int] = Field(default=0)
    ldl_f2_g: Optional[int] = Field(default=0)
    ldl_f2_h: Optional[int] = Field(default=0)
    ldl_g1_a: Optional[int] = Field(default=0)
    ldl_g1_a1: Optional[float] = Field(default=0)
    ldl_g1_a2: Optional[int] = Field(default=0)
    ldl_g1_a3: int = Field()
    ldl_g1_b: Optional[int] = Field(default=0)
    ldl_g1_c: Optional[int] = Field(default=0)
    ldl_g1_d: Optional[int] = Field(default=0)
    ldl_g1_e: Optional[int] = Field(default=0)
    ldl_g1_f: Optional[int] = Field(default=0)
    ldl_g1_g: Optional[int] = Field(default=0)
    ldl_g2_a: Optional[int] = Field(default=0)
    ldl_g2_b: Optional[int] = Field(default=0)
    ldl_g2_b1: Optional[int] = Field(default=0)
    ldl_g2_b2: Optional[int] = Field(default=0)
    ldl_g2_b3: Optional[int] = Field(default=0)
    ldl_g2_c: Optional[int] = Field(default=0)
    ldl_g2_c1: int = Field()
    ldl_g2_c2: int = Field()
    ldl_g3_a: Optional[int] = Field(default=0)
    ldl_g3_b: Optional[int] = Field(default=0)
    ldl_g4: Optional[int] = Field(default=0)
    ldl_h1: Optional[int] = Field(default=0)
    ldl_h21_a: Optional[int] = Field(default=0)
    ldl_h21_b1: Optional[float] = Field(default=0)
    ldl_h21_b2: Optional[str] = Field(max_length=8, default="")
    ldl_h22: Optional[int] = Field(default=0)
    ldl_h23_a: Optional[int] = Field(default=0)
    ldl_h23_b1: Optional[float] = Field(default=0)
    ldl_h23_b2: Optional[str] = Field(max_length=8, default="")
    ldl_h3_a: Optional[int] = Field(default=0)
    ldl_h3_b: Optional[int] = Field(default=0)
    ldl_h3_b1: int = Field()
    ldl_h3_b2: int = Field()
    ldl_h4_a: Optional[str] = Field(max_length=1, default="")
    ldl_h4_b: Optional[str] = Field(max_length=1, default="")
    ldl_i1_a1: Optional[int] = Field(default=0)
    ldl_i1_a2: Optional[int] = Field(default=0)
    ldl_i1_a3: Optional[int] = Field(default=0)
    ldl_i1_a4: Optional[int] = Field(default=0)
    ldl_i1_b1: Optional[int] = Field(default=0)
    ldl_i1_b2: Optional[int] = Field(default=0)
    ldl_i1_b3: Optional[int] = Field(default=0)
    ldl_i1_b4: Optional[int] = Field(default=0)
    ldl_i2_a: Optional[int] = Field(default=0)
    ldl_i2_b: Optional[str] = Field(max_length=8, default="")
    ldl_i3: Optional[int] = Field(default=0)
    ldl_i4_a: Optional[int] = Field(default=0)
    ldl_i4_b: Optional[int] = Field(default=0)
    ldl_i4_b1: Optional[int] = Field(default=0)
    ldl_i4_b2: Optional[int] = Field(default=0)
    ldl_i4_c: Optional[int] = Field(default=0)
    ldl_i4_d: Optional[int] = Field(default=0)
    ldl_i4_e: Optional[int] = Field(default=0)
    ldl_i5_a: Optional[int] = Field(default=0)
    ldl_i5_b: Optional[int] = Field(default=0)
    ldl_i5_c: Optional[int] = Field(default=0)
    ldl_i5_d: Optional[int] = Field(default=0)
    ldl_i5_d1: Optional[int] = Field(default=0)
    ldl_i5_d2: Optional[int] = Field(default=0)
    ldl_i5_e: Optional[int] = Field(default=0)
    ldl_i5_e1: Optional[int] = Field(default=0)
    ldl_i5_e2: Optional[int] = Field(default=0)
    ldl_i5_f: Optional[int] = Field(default=0)
    ldl_i5_g: Optional[int] = Field(default=0)
    ldl_i5_h: int = Field()
    ldl_j1: Optional[int] = Field(default=0)
    ldl_j2: Optional[int] = Field(default=0)
    ldl_j3: Optional[int] = Field(default=0)
    ldl_j4: Optional[int] = Field(default=0)
    ldl_k1_a: Optional[int] = Field(default=0)
    ldl_k1_a1: int = Field()
    ldl_k1_b: Optional[int] = Field(default=0)
    ldl_k1_c: Optional[int] = Field(default=0)
    ldl_k1_d: Optional[int] = Field(default=0)
    ldl_k1_e: Optional[int] = Field(default=0)
    ldl_k1_e1: Optional[float] = Field(default=0)
    ldl_k1_e2: Optional[int] = Field(default=0)
    ldl_k1_f: Optional[int] = Field(default=0)
    ldl_k1_g: Optional[int] = Field(default=0)
    ldl_k1_h: Optional[int] = Field(default=0)
    ldl_k1_i: Optional[int] = Field(default=0)
    ldl_k1_i1: int = Field()
    ldl_k1_i2: int = Field()
    ldl_k1_j: Optional[int] = Field(default=0)
    ldl_k1_j1: Optional[int] = Field(default=0)
    ldl_k1_j2: Optional[int] = Field(default=0)
    ldl_k1_k: Optional[int] = Field(default=0)
    ldl_k1_l: Optional[int] = Field(default=0)
    ldl_k2: Optional[int] = Field(default=0)
    ldl_adl: Optional[int] = Field(default=0)
    ldl_doctor: Optional[int] = Field(default=0)
    ldl_doctorname: Optional[str] = Field(max_length=50, default="")
    ldl_tester: Optional[str] = Field(max_length=20, default="")
    ldl_username: Optional[str] = Field(max_length=20, default="")
    ldl_insertdate: Optional[str] = Field(max_length=20, default="")
    ldl_updateuser: Optional[str] = Field(max_length=20, default="")
    ldl_updatedate: Optional[str] = Field(max_length=20, default="")
    ldl_docdate: Optional[str] = Field(max_length=20, default="")
    ldl_nurdate: Optional[str] = Field(max_length=20, default="")
    ldl_etc1: Optional[str] = Field(max_length=255, default="")
    ldl_etc2: Optional[str] = Field(max_length=255, default="")
    ldl_etc3: Optional[str] = Field(max_length=255, default="")
    ldl_etc4: Optional[str] = Field(max_length=255, default="")
    ldl_etc5: Optional[str] = Field(max_length=255, default="")
    ldl_etc6: Optional[str] = Field(max_length=255, default="")
    ldl_etc7: Optional[str] = Field(max_length=255, default="")
    ldl_etc8: Optional[str] = Field(default=None)
    ldl_etc9: Optional[str] = Field(max_length=255, default="")
    ldl_etc10: Optional[str] = Field(max_length=255, default="")
    ldl_dc: str = Field(max_length=1, default="0")
    ldl_dcdate: Optional[str] = Field(max_length=20, default="")
    ldl_dcuser: Optional[str] = Field(max_length=20, default="")
    ldl_docuser: Optional[str] = Field(max_length=20, default="")
    ldl_nuruser: Optional[str] = Field(max_length=20, default="")
    ldl_insign: Optional[bytes] = Field(default=None)
    ldl_upsign: Optional[bytes] = Field(default=None)
    ldl_dcsign: Optional[bytes] = Field(default=None)
    ldl_docsign: Optional[bytes] = Field(default=None)
    ldl_nursign: Optional[bytes] = Field(default=None)
    ldl_incert: Optional[str] = Field(default=None)
    ldl_upcert: Optional[str] = Field(default=None)
    ldl_dccert: Optional[str] = Field(default=None)
    ldl_doccert: Optional[str] = Field(default=None)
    ldl_nurcert: Optional[str] = Field(default=None)
    ldl_etc11: Optional[str] = Field(max_length=255, default="")
    ldl_etc12: Optional[str] = Field(max_length=255, default="")
    ldl_etc13: Optional[str] = Field(max_length=255, default="")
    ldl_etc14: Optional[str] = Field(max_length=255, default="")
    ldl_etc15: Optional[str] = Field(max_length=255, default="")
    ldl_enctype: Optional[str] = Field(max_length=1, default="Y")
    ldl_linetext: Optional[str] = Field(default=None)
    ldl_etc16: Optional[str] = Field(max_length=255, default="")
    ldl_etc17: Optional[str] = Field(max_length=255, default="")
    ldl_etc18: Optional[str] = Field(max_length=255, default="")
    ldl_etc19: Optional[str] = Field(max_length=255, default="")
    ldl_etc20: Optional[str] = Field(max_length=255, default="")